===
Mau
===

**Mau** is a lightweight a lightweight markup language heavily inspired by AsciiDoc_, Asciidoctor_ and Markdown_.

The documentation is hosted at TDCB_.
   
Contents
========

.. toctree::
   :maxdepth: 2

   License <license>
   Authors <authors>
   Changelog <changelog>
   Module Reference <api/modules>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _AsciiDoc: https://asciidoctor.org/docs/what-is-asciidoc
.. _Asciidoctor: https://asciidoctor.org/
.. _Markdown: https://daringfireball.net/projects/markdown/
.. _TDCB: htts://www.thedigitalcatbooks.com
